#' @keywords internal
#' @concept Bank of England
#' @concept interest rates
#' @concept monetary policy
#' @concept SONIA
#' @concept yield curve
#' @concept exchange rates
#' @concept mortgage rates
#' @concept money supply
#' @concept UK central bank
"_PACKAGE"
