% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/clear_cache.R
\name{clear_cache}
\alias{clear_cache}
\title{Clear locally cached Bank of England data}
\usage{
clear_cache(max_age_days = NULL)
}
\arguments{
\item{max_age_days}{Numeric or \code{NULL}. If specified, only removes files
older than this many days. If \code{NULL} (the default), removes all
cached files.}
}
\value{
Invisibly returns the number of files removed.
}
\description{
Removes cached data files downloaded from the Bank of England.
}
\examples{
\donttest{
op <- options(boe.cache_dir = tempdir())
# Remove files older than 7 days
clear_cache(max_age_days = 7)

# Remove everything
clear_cache()
options(op)
}

}
\seealso{
Other data access: 
\code{\link{boe_get}()}
}
\concept{data access}
