% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/boe_exchange_rate.R
\name{list_exchange_rates}
\alias{list_exchange_rates}
\title{List available exchange rate currencies}
\usage{
list_exchange_rates()
}
\value{
A data frame with columns:
\describe{
\item{currency}{Character. ISO currency code.}
\item{description}{Character. Currency name.}
\item{boe_code}{Character. BoE series code.}
}
}
\description{
Returns a data frame of currency codes and descriptions available
from the Bank of England exchange rate series.
}
\examples{
list_exchange_rates()

}
\seealso{
Other exchange rates: 
\code{\link{boe_exchange_rate}()}
}
\concept{exchange rates}
